# Twita

> **WIP**

A library to fetch Twitter data using Twitter API v2 (hidden).

<!-- [![Latest Version](https://img.shields.io/pypi/v/twita.svg)](https://pypi.python.org/pypi/twita)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/twita)](https://pypi.python.org/pypi/twita)
[![CI](https://github.com/countertek/twita/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/countertek/twita/actions/workflows/ci.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![GitHub license](https://img.shields.io/github/license/countertek/twita)](https://github.com/countertek/twita/blob/main/LICENSE) -->

<!-- **[Documentation](https://countertek.github.io/twita)**
**·**
**[Replit Playground](https://replit.com/@darekaze/twita-examples#main.py)** -->

## Why this library?

> To be filled.

**twita** tries to counter these problems to provide these features:

- No authentication (API key) is needed to access the data.
- Fully Async based.
- Proxy support via [httpx](https://www.python-httpx.org/advanced/#http-proxying).

## Install

You can install this library easily from pypi:

```bash
# with pip
pip install twita

# with poetry
poetry add twita
```

## License

[![GNU LGPLv3 Image](https://www.gnu.org/graphics/lgplv3-147x51.png)](https://www.gnu.org/licenses/lgpl-3.0.html)

Copyright (C) 2022-present DaRekaze \<https://github.com/darekaze>

Twita is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Twita is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with Twita. If not, see <http://www.gnu.org/licenses/>.
